/**
 * Zaměstnance, který má základní týdenní mzdu a navíc provizi z
 * prodaného zboží.
 */
public class BasePlusCommissionEmployee4 {

	/**
	 * Základní týdenní mzda.
	 */
	private double baseSalary;

	/**
	 * Vložená třída, jejíž metody budeme poskytovat jako by sme dědili
	 * */
	private CommissionEmployee3 CE3;

	/**
	 * Vytvoří novou instanci třídy BasePlusCommissionEmployee4.
	 * 
	 * @param first
	 *            křestní jméno zaměstnance.
	 * @param last
	 *            příjmení zaměstnance.
	 * @param ssn
	 *            číslo sociálního pojištění zaměstnance.
	 * @param sales
	 *            týdenní hrubý prodej zaměstnance.
	 * @param rate
	 *            podíl provize zaměstnance.
	 * @param salary
	 *            základní týdenní mzda zaměstnance.
	 */
	public BasePlusCommissionEmployee4(String first, String last,
			String ssn, double sales, double rate, double salary) {
		// explicitní volání konstruktoru předka
		CE3 = new CommissionEmployee3(first, last, ssn, sales, rate);

		setBaseSalary(salary);
	}

	/**
	 * Nastaví základní týdenní mzdu zaměstnance.
	 * 
	 * @param salary
	 *            nastavovaná základní týdenní mzda zaměstnance.
	 */
	public void setBaseSalary(double salary) {
		baseSalary = (salary < 0.0) ? 0.0 : salary;
	}

	/**
	 * Vrátí základní týdenní mzdu zaměstnance.
	 * 
	 * @return základní týdenní mzdu zaměstnance.
	 */
	public double getBaseSalary() {
		return baseSalary;
	}

	/**
	 * Vrátí týdenní výdělek zaměstnance.
	 * 
	 * @return týdenní výdělek zaměstnance.
	 */
	public double earnings() {
		return CE3.earnings() + getBaseSalary();
	}

	@Override
	public String toString() {
		return String.format(
				"%s: %s %s\n%s: %s\n%s: %.2f\n%s: %.2f\n%s: %.2f",
				"komisní zaměstnanec se základní mzdou",
				getFirstName(), getLastName(),
				"číslo sociálního pojištění",
				getSocialSecurityNumber(), "hrubý prodej",
				getGrossSales(), "podíl provize",
				getCommissionRate(), "základní mzda",
				getBaseSalary());
	}

	/*
	 * Následují metody, které poskytují přístup k třídě CE3, jako by se od ní dědilo
	 * Je potřeba definovat všechny metody, které budeme potřebovat
	 */

	/**
	 * Přístupová metoda k  metodě atribugu CE3 stejného jména
	 * */
	public String getFirstName() { return CE3.getFirstName(); }

	public void setFirstName(String first) {
		CE3.setFirstName(first);
	}
	/**
	 * Přístupová metoda k  metodě atribugu CE3 stejného jména
	 * */
	public String getLastName() { return CE3.getLastName(); }

	public void setLastName(String last) {
		CE3.setLastName(last);
	}
	/**
	 * Přístupová metoda k  metodě atribugu CE3 stejného jména
	 * */
	public String getSocialSecurityNumber() { return CE3.getSocialSecurityNumber(); }

	public void setSocialSecurityNumber(String ssn) {
		CE3.setSocialSecurityNumber(ssn);
	}
	/**
	 * Přístupová metoda k  metodě atribugu CE3 stejného jména
	 * */
	public double getGrossSales() { return CE3.getGrossSales(); }

	public void setGrossSales(double sales) {
		CE3.setGrossSales(sales);
	}
	/**
	 * Přístupová metoda k  metodě atribugu CE3 stejného jména
	 * */
	public double getCommissionRate() { return CE3.getCommissionRate(); }

	public void setCommissionRate(double rate) {
		CE3.setCommissionRate(rate);
	}
}
